@@ -61,7 +61,7 @@
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="94"/>
         <source>Clear input on launching</source>
-        <translation type="unfinished">Garbitu sarrera abiarazteko</translation>
+        <translation>Garbitu sarrera abiarazteko</translation>
     </message>
     <message>
         <location filename="../configuredialog/configuredialog.ui" line="111"/>
@@ -114,7 +114,7 @@
     <message>
         <location filename="../dialog.cpp" line="409"/>
         <source>Show/hide runner dialog</source>
-        <translation type="unfinished"></translation>
+        <translation>Erakutsi/ezkutatu krunner-en elkarrizketa-koadroa</translation>
     </message>
 </context>
 <context>
